==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/servicecatalog/kotlin/inputs/GetLaunchPathsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicecatalog.kotlin.inputs

import com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getLaunchPaths.
 * @property acceptLanguage Language code. Valid values: `en` (English), `jp` (Japanese), `zh` (Chinese). Default value is `en`.
 * @property productId Product identifier.
 * The following arguments are optional:
 */
public data class GetLaunchPathsPlainArgs(
    public val acceptLanguage: String? = null,
    public val productId: String,
) : ConvertibleToJava<com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs> {
    override fun toJava(): com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs =
        com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs.builder()
            .acceptLanguage(acceptLanguage?.let({ args0 -> args0 }))
            .productId(productId.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLaunchPathsPlainArgs].
 */
@PulumiTagMarker
public class GetLaunchPathsPlainArgsBuilder internal constructor() {
    private var acceptLanguage: String? = null

    private var productId: String? = null

    /**
     * @param value Language code. Valid values: `en` (English), `jp` (Japanese), `zh` (Chinese). Default value is `en`.
     */
    @JvmName("kgqigdaqlsyodocb")
    public suspend fun acceptLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.acceptLanguage = mapped
    }

    /**
     * @param value Product identifier.
     * The following arguments are optional:
     */
    @JvmName("olfcoftklveffkgh")
    public suspend fun productId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productId = mapped
    }

    internal fun build(): GetLaunchPathsPlainArgs = GetLaunchPathsPlainArgs(
        acceptLanguage = acceptLanguage,
        productId = productId ?: throw PulumiNullFieldException("productId"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/servicecatalog/kotlin/inputs/GetLaunchPathsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicecatalog.kotlin.inputs

import com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getLaunchPaths.
 * @property acceptLanguage Language code. Valid values: `en` (English), `jp` (Japanese), `zh` (Chinese). Default value is `en`.
 * @property productId Product identifier.
 * The following arguments are optional:
 */
public data class GetLaunchPathsPlainArgs(
    public val acceptLanguage: String? = null,
    public val productId: String,
) : ConvertibleToJava<com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs> {
    override fun toJava(): com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs =
        com.pulumi.aws.servicecatalog.inputs.GetLaunchPathsPlainArgs.builder()
            .acceptLanguage(acceptLanguage?.let({ args0 -> args0 }))
            .productId(productId.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLaunchPathsPlainArgs].
 */
@PulumiTagMarker
public class GetLaunchPathsPlainArgsBuilder internal constructor() {
    private var acceptLanguage: String? = null

    private var productId: String? = null

    /**
     * @param value Language code. Valid values: `en` (English), `jp` (Japanese), `zh` (Chinese). Default value is `en`.
     */
    @JvmName("raivwnwlsxasvgpg")
    public suspend fun acceptLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.acceptLanguage = mapped
    }

    /**
     * @param value Product identifier.
     * The following arguments are optional:
     */
    @JvmName("ieaotciuexwyyhih")
    public suspend fun productId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productId = mapped
    }

    internal fun build(): GetLaunchPathsPlainArgs = GetLaunchPathsPlainArgs(
        acceptLanguage = acceptLanguage,
        productId = productId ?: throw PulumiNullFieldException("productId"),
    )
}
